==> Paws-0.32.tar.gz: Paws-0.32/lib/Paws/EC2/DisassociateIamInstanceProfile.pm <==

package Paws::EC2::DisassociateIamInstanceProfile;
  use Moose;
  has AssociationId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateIamInstanceProfile');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DisassociateIamInstanceProfileResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DisassociateIamInstanceProfile - Arguments for method DisassociateIamInstanceProfile on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateIamInstanceProfile on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method DisassociateIamInstanceProfile.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateIamInstanceProfile.

As an example:

  $service_obj->DisassociateIamInstanceProfile(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AssociationId => Str

The ID of the IAM instance profile association.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateIamInstanceProfile in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/EC2/DisassociateIamInstanceProfile.pm <==

package Paws::EC2::DisassociateIamInstanceProfile;
  use Moose;
  has AssociationId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateIamInstanceProfile');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DisassociateIamInstanceProfileResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DisassociateIamInstanceProfile - Arguments for method DisassociateIamInstanceProfile on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateIamInstanceProfile on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method DisassociateIamInstanceProfile.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateIamInstanceProfile.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
    my $DisassociateIamInstanceProfileResult =
      $ec2->DisassociateIamInstanceProfile(
      AssociationId => 'MyString',

      );

    # Results:
    my $IamInstanceProfileAssociation =
      $DisassociateIamInstanceProfileResult->IamInstanceProfileAssociation;

    # Returns a L<Paws::EC2::DisassociateIamInstanceProfileResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/DisassociateIamInstanceProfile>

=head1 ATTRIBUTES


=head2 B<REQUIRED> AssociationId => Str

The ID of the IAM instance profile association.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateIamInstanceProfile in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
